==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/list/search/by-name.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/list/search/by-name/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Wed, 22 May 2024 19:50:16 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "0877b5c5-5613-4878-4a1b-5e645ca9b3a6", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "A-EY14_mfNOKm-ql-U51ousHnJclv-QF0gaGICSSWM53tqplkb0IYA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Wed, 22 May 2024 19:50:16 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "0877b5c5-5613-4878-4a1b-5e645ca9b3a6", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "A-EY14_mfNOKm-ql-U51ousHnJclv-QF0gaGICSSWM53tqplkb0IYA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 
    0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 
    0x2d, 0x6e, 0x61, 0x6d, 0x65, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 
    0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 
    0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 
    0x69, 0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x6e, 0x61, 0x6d, 0x65, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1716407416, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.4e-05, 
    connect = 0, pretransfer = 0.000155, starttransfer = 0.332077, 
    total = 0.332106)), class = "response")

==> ctxR_1.1.3.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/list/search/by-name.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/list/search/by-name/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:35:07 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "1d29b9a3-3bdd-4ea5-622d-f37e824828dd", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "b1mWQx22Y5Mq_l5xfOIG6R4_fTyzYU8aCHRRbFetnbSdiGKPwTt9mg=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:35:07 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "1d29b9a3-3bdd-4ea5-622d-f37e824828dd", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "b1mWQx22Y5Mq_l5xfOIG6R4_fTyzYU8aCHRRbFetnbSdiGKPwTt9mg=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 
    0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 
    0x2d, 0x6e, 0x61, 0x6d, 0x65, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 
    0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 
    0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 
    0x69, 0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x6e, 0x61, 0x6d, 0x65, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1731080107, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 6.5e-05, 
    connect = 0, pretransfer = 0.00019, starttransfer = 0.138059, 
    total = 0.138094)), class = "response")
